@@ -21,7 +21,7 @@ class Conv(Module):
     """
 
     # pytree
-    params: tp.Optional[tp.Mapping[str, types.Parameter]]
+    params: types.Parameter[tp.Mapping[str, jnp.ndarray], None]
 
     # props
     features_in: int
@@ -78,6 +78,7 @@ class Conv(Module):
             kernel_init: initializer for the convolutional kernel.
             bias_init: initializer for the bias.
         """
+        super().__init__()
         self.features_in = features_in
         self.module = flax_module.Conv(
             features=features_out,
